@@ -5,6 +5,7 @@ from unearth import Link
 
 from pdm.models.requirements import parse_requirement
 from pdm.models.specifiers import PySpecSet
+from pdm.pytest import Distribution
 from pdm.utils import path_to_url
 from tests import FIXTURES
 
@@ -24,6 +25,20 @@ def test_add_package(project, working_set, dev_option, pdm):
         assert package in working_set
 
 
+def test_add_package_no_lock(project, working_set, dev_option, pdm):
+    pdm(["add", *dev_option, "--frozen-lockfile", "-v", "requests"], obj=project, strict=True)
+    group = (
+        project.pyproject.settings["dev-dependencies"]["dev"]
+        if dev_option
+        else project.pyproject.metadata["dependencies"]
+    )
+
+    assert group[0] == "requests>=2.19.1"
+    assert not project.lockfile.exists()
+    for package in ("requests", "idna", "chardet", "urllib3", "certifi"):
+        assert package in working_set
+
+
 def test_add_command(project, pdm, mocker):
     do_add = mocker.patch("pdm.cli.commands.add.Command.do_add")
     pdm(["add", "requests"], obj=project)
@@ -263,9 +278,9 @@ def test_add_editable_package_with_extras(project, working_set, pdm):
 
 
 def test_add_package_with_local_version(project, repository, working_set, pdm):
-    repository.add_candidate("foo", "1.0-alpha.0+local")
-    pdm(["add", "foo"], obj=project, strict=True)
-    assert working_set["foo"].version == "1.0-alpha.0+local"
+    repository.add_candidate("foo", "1.0a0+local")
+    pdm(["add", "-v", "foo"], obj=project, strict=True)
+    assert working_set["foo"].version == "1.0a0+local"
     dependencies, _ = project.use_pyproject_dependencies("default")
     assert dependencies[0] == "foo>=1.0a0"
 
@@ -287,3 +302,22 @@ def test_add_group_to_lockfile_without_package(project, working_set, pdm):
     pdm(["add", "--group", "tz"], obj=project, strict=True)
     assert project.lockfile.groups == ["default", "tz"]
     assert "pytz" in working_set
+
+
+def test_add_update_reuse_installed(project, working_set, repository, pdm):
+    working_set["foo"] = Distribution("foo", "1.0.0")
+    repository.add_candidate("foo", "1.0.0")
+    repository.add_candidate("foo", "1.1.0")
+    pdm(["add", "--update-reuse-installed", "foo"], obj=project, strict=True)
+    locked_candidates = project.locked_repository.all_candidates
+    assert locked_candidates["foo"].version == "1.0.0"
+
+
+def test_add_update_reuse_installed_config(project, working_set, repository, pdm):
+    working_set["foo"] = Distribution("foo", "1.0.0")
+    repository.add_candidate("foo", "1.0.0")
+    repository.add_candidate("foo", "1.1.0")
+    project.project_config["strategy.update"] = "reuse-installed"
+    pdm(["add", "foo"], obj=project, strict=True)
+    locked_candidates = project.locked_repository.all_candidates
+    assert locked_candidates["foo"].version == "1.0.0"
