@@ -8,7 +8,7 @@ PYTHON_VERSION = f"{sys.version_info[0]}.{sys.version_info[1]}"
 
 
 def test_init_validate_python_requires(project_no_init, pdm):
-    result = pdm(["init"], input="\n\n\n\n\n3.7\n", obj=project_no_init)
+    result = pdm(["init"], input="\n\n\n\n\n\n\n3.7\n", obj=project_no_init)
     assert result.exit_code != 0
     assert "InvalidSpecifier" in result.stderr
 
@@ -18,19 +18,20 @@ def test_init_command(project_no_init, pdm, mocker):
         "pdm.cli.commands.init.get_user_email_from_git",
         return_value=("Testing", "me@example.org"),
     )
-    pdm(["init"], input="\n\n\n\n\n\n", strict=True, obj=project_no_init)
+    pdm(["init"], input="\ntest-project\n\n\n\n\n\n\n", strict=True, obj=project_no_init)
     python_version = f"{project_no_init.python.major}.{project_no_init.python.minor}"
     data = {
         "project": {
             "authors": [{"email": "me@example.org", "name": "Testing"}],
             "dependencies": [],
-            "description": "",
+            "description": "Default template for PDM package",
             "license": {"text": "MIT"},
-            "name": "",
-            "requires-python": f">={python_version}",
+            "name": "test-project",
+            "requires-python": f"=={python_version}.*",
             "readme": "README.md",
-            "version": "",
+            "version": "0.1.0",
         },
+        "tool": {"pdm": {"distribution": False}},
     }
 
     with open(project_no_init.root.joinpath("pyproject.toml"), "rb") as fp:
@@ -44,7 +45,7 @@ def test_init_command_library(project_no_init, pdm, mocker):
     )
     result = pdm(
         ["init"],
-        input="\ny\ntest-project\n\nTest Project\n1\n\n\n\n\n",
+        input="\ntest-project\n\ny\nTest Project\n1\n\n\n\n\n",
         obj=project_no_init,
     )
     assert result.exit_code == 0
@@ -61,6 +62,7 @@ def test_init_command_library(project_no_init, pdm, mocker):
             "version": "0.1.0",
         },
         "build-system": {"build-backend": "setuptools.build_meta", "requires": ["setuptools>=61", "wheel"]},
+        "tool": {"pdm": {"distribution": True}},
     }
 
     with open(project_no_init.root.joinpath("pyproject.toml"), "rb") as fp:
@@ -89,13 +91,14 @@ def test_init_non_interactive(project_no_init, pdm, mocker):
         "project": {
             "authors": [{"email": "me@example.org", "name": "Testing"}],
             "dependencies": [],
-            "description": "",
+            "description": "Default template for PDM package",
             "license": {"text": "MIT"},
-            "name": "",
-            "requires-python": f">={python_version}",
+            "name": project_no_init.root.name,
+            "requires-python": f"=={python_version}.*",
             "readme": "README.md",
-            "version": "",
+            "version": "0.1.0",
         },
+        "tool": {"pdm": {"distribution": False}},
     }
 
     with open(project_no_init.root.joinpath("pyproject.toml"), "rb") as fp:
@@ -105,7 +108,7 @@ def test_init_non_interactive(project_no_init, pdm, mocker):
 def test_init_auto_create_venv(project_no_init, pdm, mocker):
     mocker.patch("pdm.models.python.PythonInfo.get_venv", return_value=None)
     project_no_init.project_config["python.use_venv"] = True
-    result = pdm(["init"], input="\n\n\n\n\n\n\n", obj=project_no_init)
+    result = pdm(["init"], input="\n\n\n\n\n\n\n\n\n", obj=project_no_init)
     assert result.exit_code == 0
     assert project_no_init.python.executable.parent.parent == project_no_init.root / ".venv"
     assert ".pdm-python" in (project_no_init.root / ".gitignore").read_text()
@@ -116,7 +119,7 @@ def test_init_auto_create_venv_specify_python(project_no_init, pdm, mocker):
     project_no_init.project_config["python.use_venv"] = True
     result = pdm(
         ["init", f"--python={PYTHON_VERSION}"],
-        input="\n\n\n\n\n\n",
+        input="\n\n\n\n\n\n\n\n",
         obj=project_no_init,
     )
     assert result.exit_code == 0
@@ -127,7 +130,17 @@ def test_init_auto_create_venv_answer_no(project_no_init, pdm, mocker):
     mocker.patch("pdm.models.python.PythonInfo.get_venv", return_value=None)
     creator = mocker.patch("pdm.cli.commands.venv.backends.Backend.create")
     project_no_init.project_config["python.use_venv"] = True
-    result = pdm(["init"], input="\nn\n\n\n\n\n\n\n", obj=project_no_init)
+    result = pdm(["init"], input="\nn\n\n\n\n\n\n\n\n\n", obj=project_no_init)
     assert result.exit_code == 0
     creator.assert_not_called()
     assert project_no_init.python.executable.parent.parent != project_no_init.root / ".venv"
+
+
+def test_init_with_backend_default_library(project_no_init, pdm):
+    pdm(["init", "--backend", "flit-core"], input="\n\n\n\n\n\n\n\n\n", obj=project_no_init)
+    assert project_no_init.backend.__class__.__name__ == "FlitBackend"
+
+
+def test_init_with_backend_default_library_non_interactive(project_no_init, pdm):
+    pdm(["init", "-n", "--backend", "flit-core"], obj=project_no_init)
+    assert project_no_init.backend.__class__.__name__ == "FlitBackend"
