@@ -110,9 +110,7 @@ def test_sync_with_index_change(project, index, pdm):
     project.pyproject.metadata["requires-python"] = ">=3.6"
     project.pyproject.metadata["dependencies"] = ["future-fstrings"]
     project.pyproject.write()
-    index[
-        "/simple/future-fstrings/"
-    ] = b"""
+    index["/simple/future-fstrings/"] = b"""
     <html>
     <body>
         <h1>future-fstrings</h1>
@@ -153,11 +151,11 @@ def test_install_with_lockfile(project, pdm):
     result = pdm(["lock", "-v"], obj=project)
     assert result.exit_code == 0
     result = pdm(["install"], obj=project)
-    assert "Lock file" not in result.stderr
+    assert "Lockfile" not in result.stderr
 
     project.add_dependencies({"pytz": parse_requirement("pytz")}, "default")
     result = pdm(["install"], obj=project)
-    assert "Lock file hash doesn't match" in result.stderr
+    assert "Lockfile hash doesn't match" in result.stderr
     assert "pytz" in project.locked_repository.all_candidates
     assert project.is_lockfile_hash_match()
 
@@ -170,6 +168,25 @@ def test_install_with_dry_run(project, pdm, repository):
     assert "pytz 2019.3" in result.output
 
 
+def test_install_frozen_lockfile(project, pdm, working_set):
+    project.add_dependencies({"requests": parse_requirement("requests")}, "default")
+    result = pdm(["install", "--frozen-lockfile"], obj=project)
+    assert result.exit_code == 0
+    assert not project.lockfile.exists()
+    assert "urllib3" in working_set
+    assert "requests" in working_set
+
+
+def test_install_no_lock_deprecated(project, pdm, working_set):
+    project.add_dependencies({"requests": parse_requirement("requests")}, "default")
+    result = pdm(["install", "--no-lock"], obj=project)
+    assert result.exit_code == 0
+    assert not project.lockfile.exists()
+    assert "urllib3" in working_set
+    assert "requests" in working_set
+    assert "WARNING: --no-lock is deprecated" in result.stderr
+
+
 def test_install_check(pdm, project, repository):
     result = pdm(["install", "--check"], obj=project)
     assert result.exit_code == 1
@@ -280,3 +297,18 @@ def test_install_groups_and_lock(project, pdm, working_set):
     assert project.lockfile.groups == ["tz"]
     assert "pytz" in project.locked_repository.all_candidates
     assert "urllib3" not in project.locked_repository.all_candidates
+
+
+def test_install_requirement_with_extras(project, pdm, working_set):
+    project.add_dependencies({"requests": parse_requirement("requests==2.19.1")})
+    project.add_dependencies({"requests[socks]": parse_requirement("requests[socks]")}, to_group="socks")
+    pdm(["lock", "-Gsocks"], obj=project, strict=True)
+    pdm(["sync", "-Gsocks"], obj=project, strict=True)
+    assert "pysocks" in working_set
+
+
+def test_fix_package_type_and_update(fixture_project, pdm, working_set):
+    project = fixture_project("test-package-type-fixer")
+    pdm(["fix", "package-type"], obj=project, strict=True)
+    pdm(["update"], obj=project, strict=True)
+    assert "test-package-type-fixer" not in working_set
