@@ -77,12 +77,12 @@ def test_repository_get_release_urls(project):
 
 
 @pytest.mark.usefixtures("prepare_packages")
-def test_publish_pick_up_asc_files(project, uploaded, invoke):
+def test_publish_pick_up_asc_files(project, uploaded, pdm):
     for p in list(project.root.joinpath("dist").iterdir()):
         with open(str(p) + ".asc", "w") as f:
             f.write("fake signature")
 
-    invoke(
+    pdm(
         ["publish", "--no-build", "--username=abc", "--password=123"],
         obj=project,
         strict=True,
@@ -97,8 +97,8 @@ def test_publish_pick_up_asc_files(project, uploaded, invoke):
 
 
 @pytest.mark.usefixtures("prepare_packages")
-def test_publish_package_with_signature(project, uploaded, invoke):
-    invoke(
+def test_publish_package_with_signature(project, uploaded, pdm):
+    pdm(
         ["publish", "--no-build", "-S", "--username=abc", "--password=123"],
         obj=project,
         strict=True,
@@ -111,20 +111,20 @@ def test_publish_package_with_signature(project, uploaded, invoke):
 
 
 @pytest.mark.usefixtures("local_finder")
-def test_publish_and_build_in_one_run(fixture_project, invoke, mock_pypi):
+def test_publish_and_build_in_one_run(fixture_project, pdm, mock_pypi):
     project = fixture_project("demo-module")
-    result = invoke(["publish", "--username=abc", "--password=123"], obj=project, strict=True).output
+    result = pdm(["publish", "--username=abc", "--password=123"], obj=project, strict=True).output
 
     mock_pypi.assert_called()
     assert "Uploading demo_module-0.1.0-py3-none-any.whl" in result
-    assert "Uploading demo-module-0.1.0.tar.gz" in result
+    assert "Uploading demo_module-0.1.0.tar.gz" in result, result
     assert "https://pypi.org/project/demo-module/0.1.0/" in result
 
 
 def test_publish_cli_args_and_env_var_precedence(project, monkeypatch):
     repo = PublishCommand.get_repository(
         project,
-        Namespace(repository=None, username="foo", password="bar", ca_certs="custom.pem"),
+        Namespace(repository=None, username="foo", password="bar", ca_certs="custom.pem", verify_ssl=True),
     )
     assert repo.url == "https://upload.pypi.org/legacy/"
     assert repo.session.auth == ("foo", "bar")
@@ -138,7 +138,7 @@ def test_publish_cli_args_and_env_var_precedence(project, monkeypatch):
 
         repo = PublishCommand.get_repository(
             project,
-            Namespace(repository=None, username=None, password=None, ca_certs=None),
+            Namespace(repository=None, username=None, password=None, ca_certs=None, verify_ssl=True),
         )
         assert repo.url == "https://test.pypi.org/legacy/"
         assert repo.session.auth == ("bar", "secret")
@@ -146,8 +146,14 @@ def test_publish_cli_args_and_env_var_precedence(project, monkeypatch):
 
         repo = PublishCommand.get_repository(
             project,
-            Namespace(repository="pypi", username="foo", password=None, ca_certs="custom.pem"),
+            Namespace(repository="pypi", username="foo", password=None, ca_certs="custom.pem", verify_ssl=True),
         )
         assert repo.url == "https://upload.pypi.org/legacy/"
         assert repo.session.auth == ("foo", "secret")
         assert repo.session.verify == "custom.pem"
+
+
+def test_repository_get_credentials_from_keyring(project, keyring):
+    keyring.save_auth_info("https://test.org/upload", "foo", "barbaz")
+    repository = Repository(project, "https://test.org/upload", None, None, None)
+    assert repository.session.auth == ("foo", "barbaz")
