@@ -308,14 +308,28 @@ def test_run_script_with_args_placeholder_with_default(project, pdm, capfd, scri
     assert out.strip().splitlines()[1:] == expected
 
 
+def test_run_shell_script_with_pdm_placeholder(project, pdm):
+    project.pyproject.settings["scripts"] = {
+        "test_script": {
+            "shell": "{pdm} -V > output.txt",
+            "help": "test it won't fail",
+        }
+    }
+    project.pyproject.write()
+    with cd(project.root):
+        result = pdm(["run", "test_script"], obj=project)
+    assert result.exit_code == 0
+    assert (project.root / "output.txt").read_text().strip().startswith("PDM, version")
+
+
 def test_run_expand_env_vars(project, pdm, capfd, monkeypatch):
     (project.root / "test_script.py").write_text("import os; print(os.getenv('FOO'))")
     project.pyproject.settings["scripts"] = {
-        "test_cmd": 'python -c "foo, bar = 0, 1;print($FOO)"',
-        "test_cmd_no_expand": "python -c 'print($FOO)'",
+        "test_cmd": 'python -c "foo, bar = 0, 1;print(${FOO})"',
+        "test_cmd_no_expand": "python -c 'print(${FOO})'",
         "test_script": "python test_script.py",
         "test_cmd_array": ["python", "test_script.py"],
-        "test_shell": {"shell": "echo $FOO"},
+        "test_shell": {"shell": "echo %FOO%" if os.name == "nt" else "echo $FOO"},
     }
     project.pyproject.write()
     capfd.readouterr()
@@ -337,6 +351,35 @@ def test_run_expand_env_vars(project, pdm, capfd, monkeypatch):
         assert capfd.readouterr()[0].strip() == "bar"
 
 
+def test_run_expand_env_vars_from_config(project, pdm, capfd):
+    (project.root / "test_script.py").write_text("import os; print(os.getenv('FOO'))")
+    project.pyproject.settings["scripts"] = {
+        "test_cmd": 'python -c "foo, bar = 0, 1;print(${FOO})"',
+        "test_cmd_no_expand": "python -c 'print(${FOO})'",
+        "test_script": "python test_script.py",
+        "test_cmd_array": ["python", "test_script.py"],
+        "test_shell": {"shell": "echo %FOO%" if os.name == "nt" else "echo $FOO"},
+        "_": {"env": {"FOO": "bar"}},
+    }
+    project.pyproject.write()
+    capfd.readouterr()
+    with cd(project.root):
+        pdm(["run", "test_cmd"], obj=project)
+        assert capfd.readouterr()[0].strip() == "1"
+
+        result = pdm(["run", "test_cmd_no_expand"], obj=project)
+        assert result.exit_code == 1
+
+        pdm(["run", "test_script"], obj=project)
+        assert capfd.readouterr()[0].strip() == "bar"
+
+        pdm(["run", "test_cmd_array"], obj=project)
+        assert capfd.readouterr()[0].strip() == "bar"
+
+        pdm(["run", "test_shell"], obj=project)
+        assert capfd.readouterr()[0].strip() == "bar"
+
+
 def test_run_script_with_env_defined(project, pdm, capfd):
     (project.root / "test_script.py").write_text("import os; print(os.getenv('FOO'))")
     project.pyproject.settings["scripts"] = {"test_script": {"cmd": "python test_script.py", "env": {"FOO": "bar"}}}
