@@ -2,6 +2,7 @@ import pytest
 from resolvelib.resolvers import ResolutionImpossible, Resolver
 
 from pdm.cli.actions import resolve_candidates_from_lockfile
+from pdm.exceptions import PackageWarning
 from pdm.models.requirements import parse_requirement
 from pdm.models.specifiers import PySpecSet
 from pdm.resolver import resolve as _resolve
@@ -17,23 +18,27 @@ def resolve(project, repository):
         allow_prereleases=None,
         strategy="all",
         tracked_names=None,
+        direct_minimal_versions=False,
+        inherit_metadata=False,
     ):
         repository.environment.python_requires = PySpecSet(requires_python)
         if allow_prereleases is not None:
-            project.pyproject.settings["allow_prereleases"] = allow_prereleases
+            project.pyproject.settings.setdefault("resolution", {})["allow-prereleases"] = allow_prereleases
         requirements = []
         for line in lines:
             if line.startswith("-e "):
                 requirements.append(parse_requirement(line[3:], True))
             else:
                 requirements.append(parse_requirement(line))
-        provider = project.get_provider(strategy, tracked_names)
+        provider = project.get_provider(strategy, tracked_names, direct_minimal_versions=direct_minimal_versions)
 
         ui = project.core.ui
         with ui.open_spinner("Resolving dependencies") as spin, ui.logging("lock"):
             reporter = SpinnerReporter(spin, requirements)
             resolver = Resolver(provider, reporter)
-            mapping, *_ = _resolve(resolver, requirements, repository.environment.python_requires)
+            mapping, *_ = _resolve(
+                resolver, requirements, repository.environment.python_requires, inherit_metadata=inherit_metadata
+            )
             return mapping
 
     return resolve_func
@@ -49,8 +54,21 @@ def test_resolve_named_requirement(resolve):
     assert result["idna"].version == "2.7"
 
 
+def test_resolve_exclude(resolve, project):
+    project.pyproject.settings.setdefault("resolution", {})["excludes"] = ["urllib3"]
+    result = resolve(["requests"])
+
+    assert result["requests"].version == "2.19.1"
+    assert result["chardet"].version == "3.0.4"
+    assert result["certifi"].version == "2018.11.17"
+    assert result["idna"].version == "2.7"
+    assert "urllib3" not in result
+
+
 def test_resolve_requires_python(resolve):
-    result = resolve(["django"])
+    with pytest.warns(PackageWarning) as records:
+        result = resolve(["django"])
+    assert len(records) > 0
     assert result["django"].version == "1.11.8"
     assert "sqlparse" not in result
 
@@ -87,6 +105,19 @@ def test_resolve_allow_prereleases(resolve, repository):
 def test_resolve_with_extras(resolve):
     result = resolve(["requests[socks]"])
     assert result["pysocks"].version == "1.5.6"
+    assert result["urllib3"].version == "1.22"
+    assert result["chardet"].version == "3.0.4"
+    assert result["certifi"].version == "2018.11.17"
+    assert result["idna"].version == "2.7"
+    assert result["requests"].version == "2.19.1"
+
+
+def test_resolve_with_extras_and_excludes(resolve, project):
+    project.pyproject.settings.setdefault("resolution", {})["excludes"] = ["requests"]
+    result = resolve(["requests[socks]"])
+    assert result["pysocks"].version == "1.5.6"
+    assert "requests" not in result
+    assert "urllib3" not in result
 
 
 @pytest.mark.parametrize(
@@ -164,11 +195,15 @@ def test_resolve_conflicting_dependencies_with_overrides(project, resolve, repos
     repository.add_dependencies("foo", "0.1.0", ["hoho>=2.0"])
     repository.add_candidate("bar", "0.1.0")
     repository.add_dependencies("bar", "0.1.0", ["hoho~=1.1"])
+    repository.add_candidate("baz", "0.1.0")
+    repository.add_dependencies("baz", "0.1.0", ["hoho[extra]~=1.1"])
     repository.add_candidate("hoho", "2.1")
     repository.add_candidate("hoho", "1.5")
     project.pyproject.settings["resolution"] = {"overrides": {"hoho": overrides}}
     result = resolve(["foo", "bar"])
     assert result["hoho"].version == "2.1"
+    result = resolve(["foo", "baz"])
+    assert result["hoho"].version == "2.1"
 
 
 def test_resolve_no_available_versions(resolve, repository):
@@ -320,3 +355,52 @@ def test_resolve_extra_and_underlying_to_the_same_version(resolve, repository):
     repository.add_dependencies("bar", "0.1.0", ["foo[enc]>=0.1.0"])
     result = resolve(["foo==0.1.0", "bar"])
     assert result["foo"].version == result["foo[enc]"].version == "0.1.0"
+
+
+def test_resolve_skip_candidate_with_invalid_metadata(resolve, repository):
+    repository.add_candidate("sqlparse", "0.4.0")
+    repository.add_dependencies("sqlparse", "0.4.0", ["django>=1.11'"])
+    result = resolve(["sqlparse"], ">=3.6")
+    assert result["sqlparse"].version == "0.3.0"
+
+
+def test_resolve_direct_minimal_versions(resolve, repository, project):
+    repository.add_candidate("pytz", "2019.6")
+    project.add_dependencies({"django": parse_requirement("django")})
+    result = resolve(["django"], ">=3.6", direct_minimal_versions=True)
+    assert result["django"].version == "1.11.8"
+    assert result["pytz"].version == "2019.6"
+
+
+def test_resolve_record_markers(resolve, repository, project):
+    repository.add_candidate("A", "1.0")
+    repository.add_candidate("B", "1.0")
+    repository.add_candidate("C", "1.0")
+    repository.add_candidate("D", "1.0")
+    repository.add_candidate("E", "1.0")
+    repository.add_candidate("F", "1.0")
+    repository.add_dependencies("A", "1.0", ["B; os_name == 'posix'", "C; os_name=='nt'"])
+    # package D has transitive markers that conflict
+    repository.add_dependencies("C", "1.0", ["D; os_name!='nt'", "E; python_version < '3.8'"])
+    # package E has union markers
+    repository.add_dependencies("B", "1.0", ["E; python_version >= '3.7'"])
+    # B -> E -> F -> B has circular dependency
+    repository.add_dependencies("E", "1.0", ["F; platform_machine=='x86_64'"])
+    repository.add_dependencies("F", "1.0", ["B"])
+
+    result = resolve(["A"], ">=3.6", inherit_metadata=True)
+    assert result["a"].version == "1.0"
+    assert "d" not in result
+    assert (
+        str(result["e"].req.marker)
+        == 'python_version >= "3.7" and os_name == "posix" or python_version < "3.8" and os_name == "nt"'
+    )
+    assert (
+        str(result["f"].req.marker)
+        == 'python_version >= "3.7" and os_name == "posix" and platform_machine == "x86_64" or '
+        'python_version < "3.8" and os_name == "nt" and platform_machine == "x86_64"'
+    )
+    assert (
+        str(result["b"].req.marker) == 'os_name == "posix" or (os_name == "posix" or os_name == "nt") and '
+        'platform_machine == "x86_64" and python_version < "3.8"'
+    )
