@@ -1,18 +1,36 @@
+from __future__ import annotations
+
 import logging
 import os
+from typing import Callable
 
 import pytest
 from unearth import Link
 
+from pdm import utils
 from pdm.installers import InstallManager
 from pdm.models.candidates import Candidate
 from pdm.models.requirements import parse_requirement
-from pdm.utils import fs_supports_symlink
 from tests import FIXTURES
 
 pytestmark = pytest.mark.usefixtures("local_finder")
 
 
+@pytest.fixture()
+def supports_link(preferred: str | None, monkeypatch: pytest.MonkeyPatch) -> Callable[[str], bool]:
+    original = utils.fs_supports_link_method
+
+    def mocked_support(linker: str) -> bool:
+        if preferred is None:
+            return False
+        if preferred == "hardlink" and linker == "symlink":
+            return False
+        return original(linker)
+
+    monkeypatch.setattr(utils, "fs_supports_link_method", mocked_support)
+    return mocked_support
+
+
 def test_install_wheel_with_inconsistent_dist_info(project):
     req = parse_requirement("pyfunctional")
     candidate = Candidate(
@@ -97,8 +115,8 @@ def test_uninstall_with_console_scripts(project, use_install_cache):
     assert not os.path.exists(celery_script)
 
 
-def test_install_wheel_with_cache(project, pdm):
-    supports_symlink = fs_supports_symlink()
+@pytest.mark.parametrize("preferred", ["symlink", "hardlink", None])
+def test_install_wheel_with_cache(project, pdm, supports_link):
     req = parse_requirement("future-fstrings")
     candidate = Candidate(
         req,
@@ -108,9 +126,12 @@ def test_install_wheel_with_cache(project, pdm):
     installer.install(candidate)
 
     lib_path = project.environment.get_paths()["purelib"]
-    if supports_symlink:
+    if supports_link("symlink"):
         assert os.path.islink(os.path.join(lib_path, "future_fstrings.py"))
         assert os.path.islink(os.path.join(lib_path, "aaaaa_future_fstrings.pth"))
+    elif supports_link("link"):
+        assert os.path.isfile(os.path.join(lib_path, "future_fstrings.py"))
+        assert os.path.isfile(os.path.join(lib_path, "aaaaa_future_fstrings.pth"))
     else:
         assert os.path.isfile(os.path.join(lib_path, "aaa_future_fstrings.pth"))
         assert os.path.isfile(os.path.join(lib_path, "aaaaa_future_fstrings.pth"))
@@ -123,7 +144,7 @@ def test_install_wheel_with_cache(project, pdm):
 
     dist = project.environment.get_working_set()["future-fstrings"]
     installer.uninstall(dist)
-    if supports_symlink:
+    if supports_link("symlink") or supports_link("link"):
         assert not os.path.exists(os.path.join(lib_path, "future_fstrings.py"))
         assert not os.path.exists(os.path.join(lib_path, "aaaaa_future_fstrings.pth"))
     else:
@@ -183,3 +204,40 @@ def test_compress_file_list_for_rename():
     }
     abs_paths = {os.path.join(project_root, path) for path in paths}
     assert sorted(compress_for_rename(abs_paths)) == [os.path.join(project_root, "test-removal" + os.sep)]
+
+
+@pytest.mark.parametrize("preferred", ["symlink", "hardlink"])
+def test_install_cache_namespace_package(project, supports_link):
+    if not supports_link("symlink") and not supports_link("link"):
+        pytest.skip("This test requires symlink or hardlink support")
+
+    req = parse_requirement("pdm-backend")
+    candidate = Candidate(
+        req,
+        link=Link("http://fixtures.test/artifacts/pdm_backend-2.1.4-py3-none-any.whl"),
+    )
+    installer = InstallManager(project.environment, use_install_cache=True)
+    installer.install(candidate)
+    lib_path = project.environment.get_paths()["purelib"]
+    assert os.path.isdir(top_dir := os.path.join(lib_path, "pdm")) and not os.path.islink(top_dir)
+    assert os.path.isdir(child_dir := os.path.join(top_dir, "backend"))
+    if supports_link("symlink"):
+        assert os.path.islink(child_dir)
+    else:
+        assert os.path.isfile(os.path.join(child_dir, "__init__.py"))
+
+
+@pytest.mark.skipif(not utils.fs_supports_link_method("symlink"), reason="This test requires symlink support")
+def test_install_cache_symlink_individual(project):
+    project.project_config["install.cache_method"] = "symlink_individual"
+    req = parse_requirement("pdm-backend")
+    candidate = Candidate(
+        req,
+        link=Link("http://fixtures.test/artifacts/pdm_backend-2.1.4-py3-none-any.whl"),
+    )
+    installer = InstallManager(project.environment, use_install_cache=True)
+    installer.install(candidate)
+    lib_path = project.environment.get_paths()["purelib"]
+    for path in ("pdm", "pdm/backend"):
+        assert os.path.exists(child := os.path.join(lib_path, path)) and not os.path.islink(child)
+    assert os.path.islink(os.path.join(lib_path, "pdm/backend/__init__.py"))
