@@ -1,3 +1,5 @@
+from __future__ import annotations
+
 import os
 import sys
 import venv
@@ -9,6 +11,8 @@ from pytest_httpserver import HTTPServer
 
 from pdm.environments import PythonEnvironment
 from pdm.exceptions import PdmException
+from pdm.models.requirements import parse_requirement
+from pdm.models.specifiers import PySpecSet
 from pdm.models.venv import get_venv_python
 from pdm.utils import cd
 
@@ -328,3 +332,60 @@ def test_invoke_pdm_adding_configured_args(project, pdm, mocker):
     parser.assert_called_with(["install", "--no-self", "--no-editable", "--check"])
     pdm(["lock", "--lockfile", "pdm.2.lock"], obj=project)
     parser.assert_called_with(["lock", "--no-cross-platform", "--lockfile", "pdm.2.lock"])
+
+
+@pytest.fixture()
+def prepare_repository(repository, project):
+    repository.add_candidate("foo", "3.0", ">=3.8,<3.13")
+    repository.add_candidate("foo", "2.0", ">=3.7,<3.12")
+    repository.add_candidate("foo", "1.0", ">=3.7")
+    repository.environment.python_requires = PySpecSet(">=3.9")
+    project.add_dependencies({"foo": parse_requirement("foo")})
+
+
+@pytest.mark.usefixtures("prepare_repository")
+@pytest.mark.parametrize("is_quiet,extra_args", [(True, ("-q",)), (False, ())])
+def test_quiet_mode(pdm, project, is_quiet, extra_args, recwarn):
+    result = pdm(["lock", *extra_args], obj=project)
+
+    assert result.exit_code == 0
+    assert len(recwarn) > 0
+
+    assert 'For example, "<3.13,>=3.9"' in str(recwarn[0].message)
+    assert 'For example, "<3.12,>=3.9"' in str(recwarn[1].message)
+    assert ("to suppress these warnings" in result.stderr) is not is_quiet
+    assert project.locked_repository.all_candidates["foo"].version == "1.0"
+
+
+@pytest.mark.usefixtures("prepare_repository")
+@pytest.mark.parametrize("pattern,suppressed", [("foo", True), ("bar", False), ("*", True), ("f?o", True)])
+def test_ignore_package_warning(pdm, project, recwarn, pattern, suppressed):
+    project.pyproject.settings["ignore_package_warnings"] = [pattern]
+    result = pdm(["lock"], obj=project)
+
+    assert result.exit_code == 0
+    assert (len(recwarn) == 0) is suppressed
+
+
+def test_filter_sources_with_config(project):
+    project.pyproject.settings["source"] = [
+        {"name": "source1", "url": "https://source1.org/simple", "include_packages": ["foo", "foo-*"]},
+        {
+            "name": "source2",
+            "url": "https://source2.org/simple",
+            "include_packages": ["foo-bar", "bar*"],
+            "exclude_packages": ["baz-*"],
+        },
+        {"name": "pypi", "url": "https://pypi.org/simple"},
+    ]
+    repository = project.get_repository()
+
+    def expect_sources(requirement: str, expected: list[str]) -> bool:
+        sources = repository.get_filtered_sources(parse_requirement(requirement))
+        assert sorted([source.name for source in sources]) == sorted(expected)
+
+    expect_sources("foo", ["source1"])
+    expect_sources("foo-baz", ["source1"])
+    expect_sources("foo-bar", ["source1", "source2"])
+    expect_sources("bar-extra", ["source2"])
+    expect_sources("baz-extra", ["source1", "pypi"])
